# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/scene/SceneObjects.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.scene.SceneObject_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/scene/SceneObjects.proto',
  package='rst.scene',
  serialized_pb='\n\x1crst/scene/SceneObjects.proto\x12\trst.scene\x1a\x1brst/scene/SceneObject.proto\"<\n\x0cSceneObjects\x12,\n\x0cscene_object\x18\x01 \x03(\x0b\x32\x16.rst.scene.SceneObjectB\x12\x42\x10SceneObjectsType')




_SCENEOBJECTS = _descriptor.Descriptor(
  name='SceneObjects',
  full_name='rst.scene.SceneObjects',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='scene_object', full_name='rst.scene.SceneObjects.scene_object', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=72,
  serialized_end=132,
)

_SCENEOBJECTS.fields_by_name['scene_object'].message_type = rst.scene.SceneObject_pb2._SCENEOBJECT
DESCRIPTOR.message_types_by_name['SceneObjects'] = _SCENEOBJECTS

class SceneObjects(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _SCENEOBJECTS

  # @@protoc_insertion_point(class_scope:rst.scene.SceneObjects)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\020SceneObjectsType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/Cylinder3DFloatSet.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.Cylinder3DFloat_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/Cylinder3DFloatSet.proto',
  package='rst.geometry',
  serialized_pb='\n%rst/geometry/Cylinder3DFloatSet.proto\x12\x0crst.geometry\x1a\"rst/geometry/Cylinder3DFloat.proto\"F\n\x12\x43ylinder3DFloatSet\x12\x30\n\tcylinders\x18\x01 \x03(\x0b\x32\x1d.rst.geometry.Cylinder3DFloatB\x18\x42\x16\x43ylinder3DFloatSetType')




_CYLINDER3DFLOATSET = _descriptor.Descriptor(
  name='Cylinder3DFloatSet',
  full_name='rst.geometry.Cylinder3DFloatSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cylinders', full_name='rst.geometry.Cylinder3DFloatSet.cylinders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=91,
  serialized_end=161,
)

_CYLINDER3DFLOATSET.fields_by_name['cylinders'].message_type = rst.geometry.Cylinder3DFloat_pb2._CYLINDER3DFLOAT
DESCRIPTOR.message_types_by_name['Cylinder3DFloatSet'] = _CYLINDER3DFLOATSET

class Cylinder3DFloatSet(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CYLINDER3DFLOATSET

  # @@protoc_insertion_point(class_scope:rst.geometry.Cylinder3DFloatSet)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\026Cylinder3DFloatSetType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/generic/CpuStateCollection.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.devices.generic.CpuState_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/generic/CpuStateCollection.proto',
  package='rst.devices.generic',
  serialized_pb='\n,rst/devices/generic/CpuStateCollection.proto\x12\x13rst.devices.generic\x1a\"rst/devices/generic/CpuState.proto\"D\n\x12\x43puStateCollection\x12.\n\x07\x65lement\x18\x01 \x03(\x0b\x32\x1d.rst.devices.generic.CpuStateB\x18\x42\x16\x43puStateCollectionType')




_CPUSTATECOLLECTION = _descriptor.Descriptor(
  name='CpuStateCollection',
  full_name='rst.devices.generic.CpuStateCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='rst.devices.generic.CpuStateCollection.element', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=105,
  serialized_end=173,
)

_CPUSTATECOLLECTION.fields_by_name['element'].message_type = rst.devices.generic.CpuState_pb2._CPUSTATE
DESCRIPTOR.message_types_by_name['CpuStateCollection'] = _CPUSTATECOLLECTION

class CpuStateCollection(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CPUSTATECOLLECTION

  # @@protoc_insertion_point(class_scope:rst.devices.generic.CpuStateCollection)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\026CpuStateCollectionType')
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/geometry/Cylinder3DFloat.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.Pose_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/geometry/Cylinder3DFloat.proto',
  package='rst.geometry',
  serialized_pb='\n\"rst/geometry/Cylinder3DFloat.proto\x12\x0crst.geometry\x1a\x17rst/geometry/Pose.proto\"]\n\x0f\x43ylinder3DFloat\x12*\n\x0etransformation\x18\x01 \x02(\x0b\x32\x12.rst.geometry.Pose\x12\x0e\n\x06radius\x18\x02 \x02(\x02\x12\x0e\n\x06height\x18\x03 \x02(\x02\x42\x15\x42\x13\x43ylinder3DFloatType')




_CYLINDER3DFLOAT = _descriptor.Descriptor(
  name='Cylinder3DFloat',
  full_name='rst.geometry.Cylinder3DFloat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transformation', full_name='rst.geometry.Cylinder3DFloat.transformation', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='radius', full_name='rst.geometry.Cylinder3DFloat.radius', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='height', full_name='rst.geometry.Cylinder3DFloat.height', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=77,
  serialized_end=170,
)

_CYLINDER3DFLOAT.fields_by_name['transformation'].message_type = rst.geometry.Pose_pb2._POSE
DESCRIPTOR.message_types_by_name['Cylinder3DFloat'] = _CYLINDER3DFLOAT

class Cylinder3DFloat(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CYLINDER3DFLOAT

  # @@protoc_insertion_point(class_scope:rst.geometry.Cylinder3DFloat)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\023Cylinder3DFloatType')
# @@protoc_insertion_point(module_scope)
